Generates a custom species checklist formatted for use within the Rveg package.
This function takes a list of full botanical names and deterministically converts
them into unique, 7-character ShortName codes.
Rveg includes the following
built-in checklists:
cz_dh2012 (Default: Checklist of vascular plants of the Czech Republic)
Czechia_slovakia_2015 (Turboveg compatible checklist)
cz_kaplan2019 (Rveg generated - Kaplan et al. 2019)
wcvp_que (example WCVP subset for Quebec)
wcvp_por (example WCVP subset for Portugal)
CreateChecklist(specieslist, export = "export")Writes a .txt file containing two columns (ShortName and FullName)
to the location specified by export. The output can be then used
inside addReleve and other functions.
Character vector OR Character. Either a vector
of full botanical names in your R environment, or a path to a .txt file
containing a single column named "FullName".
Character. The output path and name for the exported checklist. Defaults to a temporary directory.
ShortName Generation Rules: The function guarantees a unique 7-character code for every species. The first 4 characters always represent a unique Genus code. The remaining 3 characters depend on the taxonomic rank:
Standard Species: Genus (4) + first 3 letters of the specific epithet (e.g., GENUEPI).
Species (sp.): Genus (4) + -SP (e.g., GENU-SP).
Hybrids (x): Genus (4) + * + first 2 letters of hybrid epithet (e.g., GENU*HY).
Aggregates (agg.): Genus (4) + # + first 2 letters of main epithet (e.g., GENU#EP).
Subspecies (ssp.): Genus (4) + first letter of main epithet + - + first letter of infra epithet (e.g., GENUE-I).
Varieties/Forms (var./f.): Genus (4) + first letter of main epithet + ; + first letter of infra epithet (e.g., GENUE;I).
Sections (sect.): Genus (4) + SE + first letter of section epithet (e.g., GENUSEE).
Note: If a 7-character code clash occurs, the 7th character is automatically adjusted using trailing letters or alphanumeric fallbacks to ensure absolute uniqueness.
# Example 1: Creating a checklist from a local txt file
CreateChecklist(
specieslist = paste0(path.package("Rveg"), "/extdata/SpeciesList"),
)
Run the code above in your browser using DataLab