| addReleve | R Documentation |
The core interactive function of the Rveg package. addReleve() launches a
console-based menu system that allows users to create new vegetation databases,
digitize new relevés, and edit existing ones. It seamlessly manages both the
species composition data (REL) and the environmental plot header data (HEAD).
Parameter start was removed.
For list of commands in addReleve menu prompt help or ?
addReleve(
database = "NEW",
save = "default",
checklist = "default",
customhead = NULL,
extrahead = NULL,
metadata = NULL
)
database |
Character. The path and name of an existing Rveg database
(e.g., |
save |
Character. The output path and name where the resulting database
files ( |
checklist |
Character. The species checklist to use. Can be a built-in
checklist (atm: |
customhead |
Character vector. A vector of strings defining completely custom header fields. Overrides the default schema. |
extrahead |
Character vector. Additional header fields to append to the end of the default or existing header schema. |
metadata |
Character vector of length 2. Used to store the Project Title
and Project Description (e.g., |
Writes two linked CSV files (Rveg database) to the location specified by save: one
containing the relevé species data (*REL.csv) and one containing the header data (*HEAD.csv).
if (interactive()) {
# Launch the interactive menu for a new database
addReleve(
database = "NEW",
save = "my_new_project",
metadata = c("Project Title", "Project Description")
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.