Learn R Programming

Rveg (version 0.1.8)

addReleve: addReleve: Digitize and Edit Relevés in an Rveg Database

Description

The core interactive function of the Rveg package. addReleve() launches a console-based menu system that allows users to create new vegetation databases, digitize new relevés, and edit existing ones. It seamlessly manages both the species composition data (REL) and the environmental plot header data (HEAD). Parameter start was removed.

For list of commands in addReleve menu prompt help or ?

Usage

addReleve(
  database = "NEW",
  save = "default",
  checklist = "default",
  customhead = NULL,
  extrahead = NULL,
  metadata = NULL
)

Value

Writes two linked CSV files (Rveg database) to the location specified by save: one containing the relevé species data (*REL.csv) and one containing the header data (*HEAD.csv).

Arguments

database

Character. The path and name of an existing Rveg database (e.g., "path/to/my_db"). Defaults to "NEW" which creates a fresh database.

save

Character. The output path and name where the resulting database files (*HEAD.csv and *REL.csv) will be exported. Defaults to a temporary directory.

checklist

Character. The species checklist to use. Can be a built-in checklist (atm: cz_dh2012, Czechia_slovakia_2015, cz_kaplan2019, wcvp_que, wcvp_por) or a file path to a custom txt checklist. Default use cz_dh2012. see function CreateChecklist.

customhead

Character vector. A vector of strings defining completely custom header fields. Overrides the default schema.

extrahead

Character vector. Additional header fields to append to the end of the default or existing header schema.

metadata

Character vector of length 2. Used to store the Project Title and Project Description (e.g., c("Alpine Flora", "Summer 2024 survey")).

Examples

Run this code
if (interactive()) {
  # Launch the interactive menu for a new database
  addReleve(
    database = "NEW",
    save = "my_new_project",
    metadata = c("Project Title", "Project Description")
  )
}

Run the code above in your browser using DataLab